@@ -23,7 +23,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: depmod.c 1.9 Sat, 22 Sep 2001 19:51:52 +1000 kaos $"
+#ident "$Id: depmod.c 1.10 Tue, 02 Oct 2001 12:28:38 +1000 kaos $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -972,6 +972,8 @@ static int addksyms(char *file_syms)
 				p = NULL;
 		}
 
+		if (p && strncmp(p, "GPLONLY_", 8) == 0)
+			p += 8;
 		if (p)
 			symtab[n_syms++] = addsym(p, mod, SYM_DEFINED, 0);
 
@@ -1003,6 +1005,8 @@ static int addksyms(char *file_syms)
 				} else
 					continue;
 			}
+			if (strncmp(p, "GPLONLY_", 8) == 0)
+				p += 8;
 			assert(n_syms < MAX_MAP_SYM);
 			symtab[n_syms++] = addsym(p, mod, SYM_DEFINED, 0);
 		}
@@ -1012,6 +1016,8 @@ static int addksyms(char *file_syms)
 			return -1;
 
 		for (ksym = ksyms; so_far < nksyms; ++so_far, ksym++) {
+			if (strncmp((char *)ksym->name, "GPLONLY_", 8) == 0)
+				((char *)ksym->name) += 8;
 			assert(n_syms < MAX_MAP_SYM);
 			symtab[n_syms++] = addsym((char *)ksym->name, mod, SYM_DEFINED, 0);
 		}
