@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_alpha.c 1.2 Sat, 22 Sep 2001 20:06:32 +1000 kaos $"
+#ident "$Id: obj_alpha.c 1.3 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -264,19 +264,12 @@ arch_create_got (struct obj_file *f)
       for (; rel < relend; ++rel)
 	{
 	  struct alpha_got_entry *ent;
-	  Elf64_Sym *extsym;
 	  struct alpha_symbol *intsym;
-	  const char *name;
 
 	  if (ELF64_R_TYPE(rel->r_info) != R_ALPHA_LITERAL)
 	    continue;
 
-	  extsym = &symtab[ELF64_R_SYM(rel->r_info)];
-	  if (extsym->st_name)
-	    name = strtab + extsym->st_name;
-	  else
-	    name = f->sections[extsym->st_shndx]->name;
-	  intsym = (struct alpha_symbol *)obj_find_symbol(&af->root, name);
+	  obj_find_relsym(intsym, f, &af->root, rel, symtab, strtab);
 
 	  for (ent = intsym->got_entries; ent ; ent = ent->next)
 	    if (ent->addend == rel->r_addend)
