@@ -22,7 +22,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: obj_hppa64.c 1.3 Sun, 06 May 2001 15:09:08 +1000 kaos $"
+#ident "$Id: obj_hppa64.c 1.4 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -373,26 +373,10 @@ arch_create_got(struct obj_file *f)
 
 	    if (need_got || need_opd || need_stub)
 	    {
-		Elf64_Sym     *extsym;
 		hppa64_symbol_t *isym;
-		const char    *name;
 		int            local;
-		unsigned long  symndx;
 
-		symndx = ELF64_R_SYM(rel->r_info);
-		extsym = &symtab[symndx];
-		if (ELF64_ST_BIND(extsym->st_info) == STB_LOCAL)
-		{
-		    isym = (hppa64_symbol_t *) f->local_symtab[symndx];
-		}
-		else
-		{
-		    if (extsym->st_name)
-			name = strtab + extsym->st_name;
-		    else
-			name = f->sections[extsym->st_shndx]->name;
-		    isym = (hppa64_symbol_t *)obj_find_symbol(f, name);
-		}
+		obj_find_relsym(isym, f, f, rel, symtab, strtab);
 		local = isym->root.secidx <= SHN_HIRESERVE;
 
 		if (need_stub)
