@@ -21,7 +21,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_load.c 1.3 Wed, 22 Aug 2001 15:19:15 +1000 kaos $"
+#ident "$Id: obj_load.c 1.4 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
 
 #include <alloca.h>
 #include <string.h>
@@ -279,7 +279,6 @@ obj_load (int fp, Elf32_Half e_type, const char *filename)
 	    /* Save the relocate type in each symbol entry.  */
 	    for (j = 0; j < nrel; ++j, ++rel)
 	      {
-		ElfW(Sym) *extsym;
 		struct obj_symbol *intsym;
 		unsigned long symndx;
 		symndx = ELFW(R_SYM)(rel->r_info);
@@ -292,23 +291,7 @@ obj_load (int fp, Elf32_Half e_type, const char *filename)
 			continue;
 		      }
 
-		    extsym = ((ElfW(Sym) *) symtab->contents) + symndx;
-		    if (ELFW(ST_BIND)(extsym->st_info) == STB_LOCAL)
-		      {
-			/* Local symbols we look up in the local table to be sure
-			   we get the one that is really intended.  */
-			intsym = f->local_symtab[symndx];
-		      }
-		    else
-		      {
-			/* Others we look up in the hash table.  */
-			const char *name;
-			if (extsym->st_name)
-			  name = strtab + extsym->st_name;
-			else
-			  name = f->sections[extsym->st_shndx]->name;
-			intsym = obj_find_symbol(f, name);
-		      }
+		    obj_find_relsym(intsym, f, f, rel, (ElfW(Sym) *)(symtab->contents), strtab);
 		    intsym->r_type = ELFW(R_TYPE)(rel->r_info);
 		  }
 	      }
