@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_reloc.c 1.3 Sat, 22 Sep 2001 20:06:32 +1000 kaos $"
+#ident "$Id: obj_reloc.c 1.4 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -308,7 +308,6 @@ obj_relocate (struct obj_file *f, ElfW(Addr) base)
 	  ElfW(Addr) value = 0;
 	  struct obj_symbol *intsym = NULL;
 	  unsigned long symndx;
-	  ElfW(Sym) *extsym = 0;
 	  const char *errmsg;
 
 	  /* Attempt to find a value to use for this relocation.  */
@@ -325,33 +324,11 @@ obj_relocate (struct obj_file *f, ElfW(Addr) base)
 		  continue;
 		}
 
-	      extsym = &symtab[symndx];
-	      if (ELFW(ST_BIND)(extsym->st_info) == STB_LOCAL)
-		{
-		  /* Local symbols we look up in the local table to be sure
-		     we get the one that is really intended.  */
-		  intsym = f->local_symtab[symndx];
-		}
-	      else
-		{
-		  /* Others we look up in the hash table.  */
-		  const char *name;
-		  if (extsym->st_name)
-		    name = strtab + extsym->st_name;
-		  else
-		    name = f->sections[extsym->st_shndx]->name;
-		  intsym = obj_find_symbol(f, name);
-		}
-
+	      obj_find_relsym(intsym, f, f, rel, symtab, strtab);
 	      value = obj_symbol_final_value(f, intsym);
 	    }
 
 #if SHT_RELM == SHT_RELA
-#if defined(__alpha__) && defined(AXP_BROKEN_GAS)
-	  /* Work around a nasty GAS bug, that is fixed as of 2.7.0.9.  */
-	  if (!extsym || !extsym->st_name ||
-	      ELFW(ST_BIND)(extsym->st_info) != STB_LOCAL)
-#endif
 	  value += rel->r_addend;
 #endif
 
